@@ -3,46 +3,49 @@ import select, threading
 from pylibcurl import Multi, Curl, const
 from Queue import Queue, Empty
 
-event_epoll2curl = {
-    select.EPOLLIN: const.CURL_CSELECT_IN,
-    select.EPOLLOUT: const.CURL_CSELECT_OUT,
-    select.EPOLLERR: const.CURL_CSELECT_ERR,
-}
+try:
+    event_epoll2curl = {
+        select.EPOLLIN: const.CURL_CSELECT_IN,
+        select.EPOLLOUT: const.CURL_CSELECT_OUT,
+        select.EPOLLERR: const.CURL_CSELECT_ERR,
+    }
 
-event_curl2epoll = {
-    const.CURL_POLL_IN: select.EPOLLIN,
-    const.CURL_POLL_OUT: select.EPOLLOUT,
-    const.CURL_POLL_INOUT: select.EPOLLIN | select.EPOLLOUT,
-}
+    event_curl2epoll = {
+        const.CURL_POLL_IN: select.EPOLLIN,
+        const.CURL_POLL_OUT: select.EPOLLOUT,
+        const.CURL_POLL_INOUT: select.EPOLLIN | select.EPOLLOUT,
+    }
 
-event_epoll_verbose = {
-    select.EPOLLIN: 'READ (Available for read)',
-    select.EPOLLOUT: 'WRITE (Available for write)',
-    select.EPOLLPRI: 'Urgent data for read',
-    select.EPOLLERR: 'ERROR (Error condition happened on the assoc. fd)',
-    select.EPOLLHUP: 'Hang up happened on the assoc. fd',
-    select.EPOLLET: 'Set Edge Trigger behavior, the default is Level Trigger behavior',
-}
+    event_epoll_verbose = {
+        select.EPOLLIN: 'READ (Available for read)',
+        select.EPOLLOUT: 'WRITE (Available for write)',
+        select.EPOLLPRI: 'Urgent data for read',
+        select.EPOLLERR: 'ERROR (Error condition happened on the assoc. fd)',
+        select.EPOLLHUP: 'Hang up happened on the assoc. fd',
+        select.EPOLLET: 'Set Edge Trigger behavior, the default is Level Trigger behavior',
+    }
 
-event_curl_verbose = {
-    const.CURL_POLL_NONE: 'register, not interested in readiness (yet)',
-    const.CURL_POLL_IN: 'READ (register, interested in read readiness)',
-    const.CURL_POLL_OUT: 'WRITE (register, interested in write readiness)',
-    const.CURL_POLL_INOUT: 'READ/WRITE (register, interested in both read and write readiness)',
-    const.CURL_POLL_REMOVE: 'unregister',
-}
+    event_curl_verbose = {
+        const.CURL_POLL_NONE: 'register, not interested in readiness (yet)',
+        const.CURL_POLL_IN: 'READ (register, interested in read readiness)',
+        const.CURL_POLL_OUT: 'WRITE (register, interested in write readiness)',
+        const.CURL_POLL_INOUT: 'READ/WRITE (register, interested in both read and write readiness)',
+        const.CURL_POLL_REMOVE: 'unregister',
+    }
 
-event_poll2curl = {
-    select.POLLIN: const.CURL_CSELECT_IN,
-    select.POLLOUT: const.CURL_CSELECT_OUT,
-    select.POLLERR: const.CURL_CSELECT_ERR,
-}
+    event_poll2curl = {
+        select.POLLIN: const.CURL_CSELECT_IN,
+        select.POLLOUT: const.CURL_CSELECT_OUT,
+        select.POLLERR: const.CURL_CSELECT_ERR,
+    }
 
-event_curl2poll = {
-    const.CURL_POLL_IN: select.POLLIN,
-    const.CURL_POLL_OUT: select.POLLOUT,
-    const.CURL_POLL_INOUT: select.POLLIN | select.POLLOUT,
-}
+    event_curl2poll = {
+        const.CURL_POLL_IN: select.POLLIN,
+        const.CURL_POLL_OUT: select.POLLOUT,
+        const.CURL_POLL_INOUT: select.POLLIN | select.POLLOUT,
+    }
+except AttributeError:
+    pass
 
 
 class Pool(threading.Thread):
@@ -64,20 +67,15 @@ class Pool(threading.Thread):
         self._size = maxconnects
 
         self._data = {}
-        self._poll = select.poll()
         self._sockets = set()
         self._complete = set() # pair(curl, socket)
 
+
         def socket_cb(curl, socket, event):
             if event == const.CURL_POLL_REMOVE:
                 self._complete.add((curl, socket))
-            else:
-                if socket not in self._sockets: 
-                    self._sockets.add(socket)
-                    self._poll.register(socket)
-
-                mask = event_curl2poll.get(event, 0)
-                self._poll.modify(socket, mask)
+            elif socket not in self._sockets:
+                self._sockets.add(socket)
             
         # TODO: timer
         def timer_cb(m, timeout):
@@ -100,7 +98,6 @@ class Pool(threading.Thread):
         # remove complete curls and sockets
         for curl, sock in self._complete:
             self._multi.remove_handle(curl)
-            self._poll.unregister(sock)
             self._sockets.remove(sock)
             
             # call callback
@@ -191,15 +188,13 @@ class Pool(threading.Thread):
         while True:
             
             while running:
-                events = self._poll.poll(1)
-                for sock, event in events:
-                    mask = event_poll2curl.get(event, 0)
+                (r, w, e) = select.select(self._sockets, self._sockets, self._sockets, 1)
+
+                sockets = set(r + w + e)
+                for sock in sockets:
+                    running = self._do_socket_action(sock, 0)
+                    self._do_remove()
 
-                    if event == select.POLLHUP:
-                        self._poll.unregister(sock)
-                    else:
-                        running = self._do_socket_action(sock, mask)
-                        self._do_remove()
 
                 self._do_add()
 
